@@ -8,6 +8,7 @@
 """
 
 from .. import __version__
+from multiprocessing import cpu_count
 import os
 
 
@@ -15,6 +16,10 @@ def get_version():
     return __version__
 
 
+def get_cpu_count():
+    return cpu_count()
+
+
 def is_dir(src_dir):
     """
     Determine whether it is a directory
